@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015-2018 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2019 Montel Laurent <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -41,7 +41,7 @@ CustomDebugSettingsPage::CustomDebugSettingsPage(QWidget *parent)
     mainLayout->addWidget(lab);
 
     QHBoxLayout *horizontalLayout = new QHBoxLayout;
-    horizontalLayout->setMargin(0);
+    horizontalLayout->setContentsMargins(0, 0, 0, 0);
     mainLayout->addLayout(horizontalLayout);
 
     QVBoxLayout *vbox = new QVBoxLayout;
